%define anolis_release 3

Name:		gperftools
Version:	2.10
Release:	%{anolis_release}%{?dist}
License:	BSD
Summary:	Very fast malloc and performance analysis tools
URL:		https://github.com/gperftools/gperftools
Source0:	https://github.com/gperftools/gperftools/releases/download/%{name}-%{version}/%{name}-%{version}.tar.gz
# Conditionalize generic dynamic tls model
Patch1:		gperftools-2.7.90-disable-generic-dynamic-tls.patch
Patch2:		0001-add-__NR_fstat-for-loongarch64.patch
Patch3:         0002-gperftools-uos-add-sw64-support.patch

BuildRequires:  gcc-c++
BuildRequires:	libunwind-devel
BuildRequires:	perl-generators
BuildRequires:	autoconf, automake, libtool
BuildRequires:	make
Requires:	gperftools-devel = %{version}-%{release}
Requires:	pprof = %{version}-%{release}

%description
Perf Tools is a collection of performance analysis tools, including a
high-performance multi-threaded malloc() implementation that works
particularly well with threads and STL, a thread-friendly heap-checker,
a heap profiler, and a cpu-profiler.

This is a metapackage which pulls in all of the gperftools (and pprof)
binaries, libraries, and development headers, so that you can use them.

%package devel
Summary:	Development libraries and headers for gperftools
Requires:	%{name}-libs = %{version}-%{release}
Provides:	google-perftools-devel = %{version}-%{release}
Obsoletes:	google-perftools-devel < 2.0

%description devel
Libraries and headers for developing applications that use gperftools.

%package libs
Summary:	Libraries provided by gperftools
Provides:	google-perftools-libs = %{version}-%{release}
Obsoletes:	google-perftools-libs < 2.0

%description libs
Libraries provided by gperftools, including libtcmalloc and libprofiler.

%package -n pprof
Summary:	CPU and Heap Profiler tool
Requires:	gv, graphviz
BuildArch:	noarch
Provides:	google-perftools = %{version}-%{release}
Obsoletes:	google-perftools < 2.0

%description -n pprof
Pprof is a heap and CPU profiler tool, part of the gperftools suite.

%package doc
Summary:        Doc files for %{name}
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description doc
Doc files for %{name}

%prep
%autosetup -p1

# Fix end-of-line encoding
sed -i 's/\r//' README_windows.txt

# No need to have exec permissions on source code
chmod -x src/*.h src/*.cc

autoreconf -ifv

%build
CFLAGS=`echo $RPM_OPT_FLAGS -fno-strict-aliasing -Wno-unused-local-typedefs -DTCMALLOC_LARGE_PAGES | sed -e 's|-fexceptions||g'`
CXXFLAGS=`echo $RPM_OPT_FLAGS -fno-strict-aliasing -Wno-unused-local-typedefs -DTCMALLOC_LARGE_PAGES | sed -e 's|-fexceptions||g'`
%configure \
%ifarch aarch64
	--disable-general-dynamic-tls \
%endif
	--disable-dynamic-sized-delete-support \
	--disable-static

# Bad rpath!
sed -i 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' libtool
sed -i 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' libtool
# Can't build with smp_mflags
make

%install
%make_install docdir=%{_pkgdocdir}/
%generate_compatibility_deps

# Delete useless files
rm -rf %{buildroot}%{_pkgdocdir}/INSTALL

%check
# Their test suite is almost always broken.
# LD_LIBRARY_PATH=./.libs make check

%files

%files -n pprof
%{_bindir}/pprof
%{_bindir}/pprof-symbolize
%{_mandir}/man1/*
%{abidir}/*-option.list

%files devel
%{_pkgdocdir}/
%{_includedir}/google/
%{_includedir}/gperftools/
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc

%files libs
%license COPYING 
%{_libdir}/*.so.*
%dir %{abidir}
%{abidir}/*.dump

%files doc
%doc AUTHORS ChangeLog INSTALL README NEWS TODO

%changelog
* Wed Mar 26 2025 zhuhongbo <zhuhongbo@uniontech.com> - 2.10-3 
- gperftools uos add sw64 support

* Tue Oct 10 2023 Jingyun Hua <huajingyun@loongson.cn> - 2.10-2
- fix build error on loongarch64

* Tue Mar 21 2023 Chunmei Xu <xuchunmei@linux.alibaba.com> - 2.10-1
- update to 2.10

* Thu Mar 16 2023 Chunmei Xu <xuchunmei@linux.alibaba.com> - 2.9.1-1
- init from upstream
